@@ -9,7 +9,9 @@ class Base:
     def __init__(self, *args, **kwargs):
         for k, v in kwargs.items():
             setattr(self, k, v)
+        #: list of attributes that will be skipped over in the `to_dict` method
         self._exempt = ["REQUEST", "_datapoint_from_client", "_exempt"]
+        #: list of datapoints that need to be retrieved from the client
         self._datapoint_from_client: Dict[str, Callable[["instauto.api.client.ApiClient"], str]] = {
             "_csrftoken": lambda c: c._session.cookies['csrftoken'],
             "device_id": lambda c: c.state.device_id,
@@ -18,6 +20,7 @@ class Base:
         }
 
     def fill(self, client) -> "Base":
+        """Fills all of the datapoints that need to be retrieved from the client."""
         attrs = dir(self)
         for k, func in self._datapoint_from_client.items():
             if k in attrs:
@@ -25,6 +28,7 @@ class Base:
         return self
 
     def to_dict(self) -> Dict[str, str]:
+        """Converts the object to a dictionary"""
         d = {}
 
         for k, v in self.__dict__.items():
