@@ -1,5 +1,5 @@
 from instauto.api.client import ApiClient
-from instauto.api.actions.structs.friendships import GetFollowers, Create
+from instauto.api.actions.structs.friendships import GetFollowers, Create, GetFollowing
 from instauto.helpers.search import get_user_id_from_username
 
 import typing
@@ -23,6 +23,20 @@ def get_followers(client: ApiClient, user_id: str, limit: int) -> typing.List[di
     return followers[:min(len(followers), limit)]
 
 
+def get_following(client: ApiClient, user_id: str, limit: int) -> typing.List[dict]:
+    obj = GetFollowing(user_id)
+
+    obj, result = client.following_get(obj)
+    following = []
+    while result and len(following) < limit:
+        following.extend(
+            result.json()["users"]
+        )
+        logger.info("Retrieved {} of following, {} more to go.".format(len(following), limit - len(following)))
+        obj, result = client.followers_get(obj)
+    return following[:min(len(following), limit)]
+
+
 def follow_user(client: ApiClient, user_id: str = None, username: str = None) -> bool:
     if user_id is not None and username is not None:
         raise ValueError("Both `user_id` and `username` are provided.")
